/** Utilities for Jupyterlab Bookmarks plugin.
 * Copyright (c) 2020, Dr. Nandor Poka, All rights reserved.
 */
import { IDisposable } from '@lumino/disposable';
import { Menu } from '@lumino/widgets';
import { CommandRegistry } from '@lumino/commands';
import { ILauncher } from '@jupyterlab/launcher';
import { INotebookTracker } from '@jupyterlab/notebook';
import { IDocumentManager } from '@jupyterlab/docmanager';
import { LabIcon } from '@jupyterlab/ui-components';
import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { Bookmark } from './bookmark';
/**
 * Prefix string used for commands and icons for this extension.
 */
export declare const commandPrefix = "jupyterlab-bookmarks-extension:";
/**
 * Verion string.
 */
export declare const VERSION = "0.5.6";
/**
 * String for plain title in the Launcher.
 */
export declare const TITLE_PLAIN = "Bookmarks";
/**
 * String for the `Bookmark management` Launcher category.
 */
export declare const TITLE_MANAGEMENT: string;
/**
 * String for the generic title in the Launcher
 */
export declare const TITLE: string;
/**
 * String for the `Disabled` bookmark Launcher category.
 */
export declare const DISABLED_TITLE: string;
/**
 * String constant for the `Factory` property to use when adding open command.
 */
export declare const NOTEBOOK_FACTORY = "Notebook";
/**
 * STring constant for the `Uncategorized` Launcher category.
 */
export declare const UNCATEGORIZED = "Uncategorized";
/**
 * Icon used for the `Add favorite` command.
 */
export declare const FAVORITE_ICON: LabIcon;
/**
 * Icon used for the `Import bookmark` command.
 */
export declare const IMPORT_ICON: LabIcon;
/**
 * Icon used for the `Export bookmark` command.
 */
export declare const EXPORT_ICON: LabIcon;
export declare const bookmarkCommands: Map<string, IDisposable>;
export declare const bookmarkLaunchers: Map<string, IDisposable>;
export declare const bookmarkMenuItems: Map<string, Menu.IItem>;
export declare const categories: Map<string, Array<IDisposable>>;
/**
 * Initialises NotebookTracker, DocumentManager, commands, and Launcer object to be shared with other modules if needed.
 * @param nbkTracker
 * @param docMan
 * @param cmds
 * @param launch
 */
export declare function initConstantsModule(nbkTracker: INotebookTracker, docMan: IDocumentManager, cmds: CommandRegistry, launch: ILauncher): void;
/**
 * Sets the global `bookmarks` object to the parameter.
 * @param incomingBookmarks `Map<string, Bookmark>` to set the `bookmarks` to
 */
export declare function setBookmarks(incomingBookmarks: Map<string, Bookmark>): void;
/**
 * Returns the `bookmark` Map.
 */
export declare function getBookmarks(): Map<string, Bookmark>;
/**
 * Getter for the settings object
 */
export declare function getSettingsObject(): ISettingRegistry.ISettings;
/**
 * Setter for the `settingsObject`.
 * @param incomingSettingsObject
 */
export declare function setSettingsObject(incomingSettingsObject: ISettingRegistry.ISettings): void;
/**
 * Getter for the `launcher` that is injected via the `ILauncher` token at runtime.
 */
export declare function getLauncher(): ILauncher;
/**
 * Getter for the `docManager` that is injected via the `IDocumentManager` token at runtime.
 */
export declare function getDocManager(): IDocumentManager;
/**
 * Getter for the application's command registry.
 */
export declare function getCommands(): CommandRegistry;
/**
 * Getter for the `notebookTracker` that is injected via the `INotebookTracker` token at runtime.
 */
export declare function getNotebookTracker(): INotebookTracker;
