/** Utilities for Jupyterlab Bookmarks plugin.
 * Copyright (c) 2020, Dr. Nandor Poka, All rights reserved.
 */
import { LabIcon } from '@jupyterlab/ui-components';
// Custom imports
import favorite from '../style/favorite.svg';
import importIcon from '../style/import.svg';
import exportIcon from '../style/export.svg';
//Global vars and exports
/**
 * Prefix string used for commands and icons for this extension.
 */
export const commandPrefix = 'jupyterlab-bookmarks-extension:';
/**
 * Verion string.
 */
export const VERSION = '0.5.6';
/**
 * String for plain title in the Launcher.
 */
export const TITLE_PLAIN = 'Bookmarks';
/**
 * String for the `Bookmark management` Launcher category.
 */
export const TITLE_MANAGEMENT = `${TITLE_PLAIN} - Management - ${VERSION}`;
/**
 * String for the generic title in the Launcher
 */
export const TITLE = `${TITLE_PLAIN} - ${VERSION} `;
/**
 * String for the `Disabled` bookmark Launcher category.
 */
export const DISABLED_TITLE = `Disabled bookmarks - ${VERSION}`;
/**
 * String constant for the `Factory` property to use when adding open command.
 */
export const NOTEBOOK_FACTORY = 'Notebook';
/**
 * STring constant for the `Uncategorized` Launcher category.
 */
export const UNCATEGORIZED = 'Uncategorized';
/**
 * Icon used for the `Add favorite` command.
 */
export const FAVORITE_ICON = new LabIcon({
    name: commandPrefix + 'FavoriteIcon',
    svgstr: favorite
});
/**
 * Icon used for the `Import bookmark` command.
 */
export const IMPORT_ICON = new LabIcon({
    name: commandPrefix + 'ImportIcon',
    svgstr: importIcon
});
/**
 * Icon used for the `Export bookmark` command.
 */
export const EXPORT_ICON = new LabIcon({
    name: commandPrefix + 'ExportIcon',
    svgstr: exportIcon
});
// internal variables accessed via exported getters, cannot be directly redefined.
let notebookTracker;
let docManager;
let commands;
let launcher;
/**
 * The extension's settings.
 */
let settingsObject = null;
/**
 * Data structure is Map<string, Bookmark> => {title: Bookmark}
 */
let bookmarks = new Map();
// exported constants
export const bookmarkCommands = new Map();
export const bookmarkLaunchers = new Map();
export const bookmarkMenuItems = new Map();
export const categories = new Map();
/**
 * Initialises NotebookTracker, DocumentManager, commands, and Launcer object to be shared with other modules if needed.
 * @param nbkTracker
 * @param docMan
 * @param cmds
 * @param launch
 */
export function initConstantsModule(nbkTracker, docMan, cmds, launch) {
    notebookTracker = nbkTracker;
    docManager = docMan;
    commands = cmds;
    launcher = launch;
}
/**
 * Sets the global `bookmarks` object to the parameter.
 * @param incomingBookmarks `Map<string, Bookmark>` to set the `bookmarks` to
 */
export function setBookmarks(incomingBookmarks) {
    bookmarks = incomingBookmarks;
}
/**
 * Returns the `bookmark` Map.
 */
export function getBookmarks() {
    return bookmarks;
}
/**
 * Getter for the settings object
 */
export function getSettingsObject() {
    return settingsObject;
}
/**
 * Setter for the `settingsObject`.
 * @param incomingSettingsObject
 */
export function setSettingsObject(incomingSettingsObject) {
    settingsObject = incomingSettingsObject;
}
/**
 * Getter for the `launcher` that is injected via the `ILauncher` token at runtime.
 */
export function getLauncher() {
    return launcher;
}
/**
 * Getter for the `docManager` that is injected via the `IDocumentManager` token at runtime.
 */
export function getDocManager() {
    return docManager;
}
/**
 * Getter for the application's command registry.
 */
export function getCommands() {
    return commands;
}
/**
 * Getter for the `notebookTracker` that is injected via the `INotebookTracker` token at runtime.
 */
export function getNotebookTracker() {
    return notebookTracker;
}
